Installation
============

This guide assumes the user is familiar with the goals and structure of the NWB standard.
If you haven't checked it out already, please read the :nwb-overview:`NWB Overview <>`

The NWBInspector tool offers convenient command-line usage via any standard Conda or Python terminal.

To install the package in any generic Python v3.9-v3.13 environment, simply type

::

    pip install nwbinspector

.. note::

    If you are a :matnwb-src:`MatNWB <>` user, please follow the :conda-install:`Conda installation instructions<>` to
    gain access to a Conda/Python terminal and base environment.


.. note::

    You can also install nwbinspector from the conda-forge release.

    ::

        conda install -c conda-forge nwbinspector
